FlutterTelegramAuthWeb class

The web implementation of the FlutterTelegramAuth platform.

Inheritance

Constructors

FlutterTelegramAuthWeb()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({required String clientId, required String redirectUri, List<String> scopes = const ['profile', 'phone']}) → Future<void>
override
login() → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void
Registers this class as the default instance of FlutterTelegramAuthPlatform.