FlutterTelegramAuthPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterTelegramAuthPlatform
Implementers

Constructors

FlutterTelegramAuthPlatform()
Constructs a FlutterTelegramAuthPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init({required String clientId, required String redirectUri, List<String> scopes = const ['profile', 'phone']}) Future<void>
login() Future<String?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterTelegramAuthPlatform
The default instance of FlutterTelegramAuthPlatform to use.
getter/setter pair